@@ -459,11 +459,11 @@ class Map(View):
 
         var markers = L.markerClusterGroup();
 <% for (const item of items) { %>
-    <% if (item.title != "") %>
+    <% if (item.title != "") { %>
 	  markers.addLayer(L.marker([<%= item.lat %>, <%= item.lon %>]).bindPopup('<%= String(item.title).replace(/\\\'/g, "\\\'") %>'));
-    <% else %>
+    <% } else { %>
 	  markers.addLayer(L.marker([<%= item.lat %>, <%= item.lon %>]).bindPopup(""));
-    <% end %>
+    <% } %>
 <% } %>
 
       map.addLayer(markers);
